Package: lhs
Version: 0.15
Date: 2017-12-19
Title: Latin Hypercube Samples
Authors@R: c(person("Rob", "Carnell", role=c("aut","cre"),
  email="bertcarnell@gmail.com"))
Author: Rob Carnell [aut, cre]
Maintainer: Rob Carnell <bertcarnell@gmail.com>
Depends: R (>= 3.4.0)
Suggests: RUnit
Description: Provides a number of methods for creating and augmenting Latin Hypercube Samples.
License: GPL (>= 2)
URL: http://lhs.r-forge.r-project.org
BugReports: http://r-forge.r-project.org/projects/lhs/
NeedsCompilation: yes
Packaged: 2017-12-20 02:13:11 UTC; carnellr
Repository: CRAN
Date/Publication: 2017-12-20 17:42:41 UTC
Built: R 3.4.1; x86_64-w64-mingw32; 2018-08-02 16:13:26 UTC; windows
Archs: x64
