Package: lhs
Title: Latin Hypercube Samples
Version: 1.1.3
Authors@R: 
    person(given = "Rob",
           family = "Carnell",
           role = c("aut", "cre"),
           email = "bertcarnell@gmail.com")
Description: Provides a number of methods for creating and augmenting Latin Hypercube Samples and Orthogonal Array Latin Hypercube Samples.
License: GPL-3
Encoding: UTF-8
Depends: R (>= 3.4.0)
LinkingTo: Rcpp
Imports: Rcpp
Suggests: testthat, assertthat, DoE.base, knitr, rmarkdown, covr
URL: https://github.com/bertcarnell/lhs
BugReports: https://github.com/bertcarnell/lhs/issues
RoxygenNote: 7.1.1
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2021-09-08 00:16:13 UTC; bertc
Author: Rob Carnell [aut, cre]
Maintainer: Rob Carnell <bertcarnell@gmail.com>
Repository: CRAN
Date/Publication: 2021-09-08 06:50:02 UTC
Built: R 4.0.5; x86_64-w64-mingw32; 2021-09-08 09:13:30 UTC; windows
Archs: x64
