useDynLib(lhs, .registration=TRUE, .fixes="C_")

export(improvedLHS, maximinLHS, randomLHS, optimumLHS, augmentLHS,
       geneticLHS, optAugmentLHS, optSeededLHS)
	   
importFrom("stats", dist, na.exclude, na.fail, na.omit, runif)
